Mortgage Rates Credit Cards Refinance Home CD Rates by Bankrate.com
Description: Compare mortgage, refinance, insurance and CD rates. Expert analysis of home loan finance topics and trends.
Keywords: compare mortgage rates loans rate cd rates refinance insurance banks credit reports

advertisement

# Welcome to Bankrate

1. What are you looking for?

2. Select a product

Next

2. Select a type

3. Select a product

Next

2. Select a product

Next

2. Select a type

3. Select a product

Next

2. Select a type

3. Select a product

Next

2. Select a credit card type

3. Select a product

Next

2. Select a type

3. Select a product

Next

2. Select a product

Next

2. Enter ZIP code

3. Select a product

Next

2. Enter ZIP code

3. Select a product

Next

1. What are you looking for?

2. Select a product

Next

2. Select a type

3. Select a product

Next

2. Select a product

Next

2. Select a type

3. Select a product

Next

2. Select a type

3. Select a product

Next

2. Select a credit card type

3. Select a product

Next

2. Select a type

3. Select a product

Next

2. Select a product

Next

2. Enter ZIP code

3. Select a product

Next

2. Enter ZIP code

3. Select a product

Next

### Top Stories

- ## Mortgages dip on overseas risk

  Global economic health kept mortgage rates low. Find out where they stand.Read more

- ## 5 dumb ways kids make you spend

  Don't fall for that pouty face. Caving in to kids' money demands can put you in the poorhouse.Read more

- ## 5 crazy things card rewards can buy

  You can make quite the purchase on your issuer's dime. See what these consumers got.Read more

- ## 5 investing myths debunked

  These investing mantras are widely believed, but are they true? Not necessarily.Read more

## Mortgages dip on concerns of overseas risk

## 5 dumb ways to spend money on your kids

## 5 true tales of crazy credit card rewards buys

## Fact or fiction: 5 investing myths debunked

### Calculators

- Mortgage calculator
- Auto loan calculator
- Loan and amortization calculator
- How much house can I afford?
- Simple Savings Calculator

### News & Commentary

- Shared LTC policies for all couples
- New Mercedes with every CD
- Jean Chatzky: Car resale-value tips
- Fed: Cheap gas fuels economy
- Big banks’ fines hit $178 billion

### Jet Off To Winter Fun

## 5 tips for a low-cost vacation

Don't break the bank to travel. Follow these tips to save money when you take time off.

- Compare major airline fees

### Get Ready to Retire

## 6 niche communities for retirees

Theme-based communities attract retirees with interests ranging from praying to playing.

- 6 savvy retirement moves
- Investing in a 401(k) plan
- Best 401(k) investments

### Roll With Rising-Rate CDs

## Flexible, rising-rate CDs

Bankrate finds these CDs offer higher returns. But are they smart investments?

- 2014 CD survey: Liquid CDs
- Rising-rate CDs cut risk?
- CD ladder: Worth a climb?

### Interest Rate Trends & Analysis

## COFI, LIBOR, Prime rate

WSJ Prime Rate | 3.25
Federal Discount Rate | 0.75
6-month LIBOR Rate | 0.33
1-year LIBOR Rate | 0.56

## Video

For a fourth consecutive week, mortgage rates fell.

## Tracking Rates

- Interest Rate Roundup
- Graph rate trends
- Your Best Interest Report
- Mortgage Analysis
- Rate Trend Index: Mortgages
- Federal Reserve coverage

- Don't co-sign
- What to buy in December
- Avoid early CD withdrawal penalty
- Home improvements
- 5 warehouse deals
- Black Friday experiences
- Mars vs. Venus on debt
- Save money on food preservation
- Frugal mom tips
- How to qualify for a mortgage
- Money tips for a new family
- Find discounts on auto insurance

### Popular Tools & Topics

- Health Insurance
- Credit Cards
- Real Estate
- Free Credit Score

- Auto Insurance
- Roth IRA
- Obamacare
- Retirement Planning

- Mortgage Rates
- Free Credit Report
- Debit Cards
- 401(k)

Find us on Google+
Connect with us
Compare Rates

REFINANCE | HOME EQUITY | AUTO | CDs | CREDIT CARDS

Product | Rate | Change | Last week
30 year fixed refi | 4.02% | 0.02 | 4.00%
15 year fixed refi | 3.15% | 0.07 | 3.08%
10 year fixed refi | 3.22% | 0.09 | 3.13%
View Rates in your area Next

Product | Rate | Change | Last week
30K FICO-based HELOC | 4.33% | 0.01 | 4.32%
50K FICO-based HELOC | 3.99% | 0.01 | 3.98%
100K FICO-based HELOC | 3.83% | --0.00 | 3.83%
View Rates in your area Next

Product | Rate | Change | Last week
60 month used car loan | 2.75% | --0.00 | 2.75%
48 month used car loan | 2.99% | --0.00 | 2.99%
60 month new car loan | 3.16% | 0.03 | 3.19%
View Rates in your area Next

Product | Rate | Change | Last week
1 Year CD | 0.99% | --0.00 | 0.99%
2 Year CD | 1.20% | 0.02 | 1.22%
5 Year CD | 1.84% | 0.03 | 1.87%
View Rates in your area Next

Product | Rate | Change | Last week
Balance Transfer Cards | 15.76% | --0.00 | 15.76%
Cash Back Cards | 16.42% | 0.02 | 16.44%
Low Interest Cards | 11.04% | --0.00 | 11.04%
Next

advertisement
advertisement
Most Read

1. Richest Oscar-winning actors and actresses
2. Celebrity house for sale: Phil Mickelson
3. 5 wealthy families who lost their fortunes
4. Does Oscar mean more money for actors?
5. 11 celebrities who served in the military

6. Hiring an appraiser to value an estate
7. Sold! Cheryl Hines' Bel Air home
8. Find your tax bracket
9. 10 best and real work-at-home jobs
10. Save money online on Cyber Monday

Bankrate Financial Advisers

- How to get out of $40K credit card debt
- What if employer didn't turn in payroll tax?
- Can highly compensated worker catch up?
- Holidays stretch Grandma's monthly budget
- Can I raid retirement to pay mortgage?

Submit a question to our experts »
WEEKLY ROUNDUP NEWSLETTER

Catch up on the latest financial news and advice for consumers.

Partner Center
advertisement
advertisement
Connect with us